@@ -1,7 +1,8 @@
 package PNI;
 use strict;
 use warnings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
+### use Smart::Comments;
 use Exporter 'import';
 use PNI::Edge;
 use PNI::Finder;
@@ -10,20 +11,14 @@ use PNI::Scenario;
 use Time::HiRes;
 
 # use PNI ':-D';
-# exports edge, node and step
-our @EXPORT_OK = qw(edge node step);
+# exports edge, node and task
+our @EXPORT_OK = qw(edge node task);
 our %EXPORT_TAGS = ( '-D' => \@EXPORT_OK );
 
 # root scenario
 my $root = PNI::Scenario->new;
 
-my $find = PNI::Finder->new;
-
-sub node_list {
-    return $find->node_list;
-}
-
-# edge $source_node => $target_node, 'out_slot_name' => 'in_slot_name'
+# return $edge
 sub edge {
     my $source_node        = shift;
     my $target_node        = shift;
@@ -39,44 +34,54 @@ sub edge {
     );
 }
 
+# return 1
 sub loop {
     while (1) {
-        step();
+        task();
         Time::HiRes::usleep(1);
     }
     return 1;
 }
 
+# return $node
 sub node {
     my $type = shift;
     return $root->add_node( type => $type, @_ );
 }
 
+# node finder
+my $find = PNI::Finder->new;
+
+# return @nodes
+sub node_list { return $find->nodes; }
+
+# return $root
 sub root { return $root; }
 
-sub step { return $root->task; }
+# return 1
+sub task { return $root->task; }
 
 1;
+__END__
 
 =head1 NAME
 
 PNI - Perl Node Interface
 
 
-
 =head1 ATTENTION
 
 This module was created to be used internally by a GUI, anyway you are free to use the scripting api if it does make sense.
 
 =head1 SYNOPSIS
 
-    use PNI ':-D';
+    use PNI ':-D'; # imports node, edge and task
 
     my $node = node 'Perlfunc::Print';
     $node->get_input('list')->set_data('Hello World !');
     $node->get_input('do_print')->set_data(1);
 
-    step;
+    task;
 
 =head1 DESCRIPTION
 
@@ -120,14 +125,15 @@ Connects an output of a node to an input of another node.
     my $target_node = node 'Another::Node';
 
     my $edge = edge 
-      $source_node => $target_node , 
+      $source_node         => $target_node , 
       'source_output_name' => 'target_input_name';
 
 This method delegates to L<PNI::Edge> constructor.
 
 =head2 C<node>
 
-Creates a node by its pni type. If you write
+Creates a node by its PNI type, that is the name of a package 
+under the PNI::Node namespace. If you write
 
     my $node = node 'Some::Node';
 
@@ -135,26 +141,26 @@ PNI do the following steps:
 
 =over 4
 
-=item 1
+=item 1)
 
 requires the PNI/Node/Some/Node.pm module.
 
-=item 2
+=item 2)
 
 creates a new PNI::Node, assigns it an id 
 and bless it as a PNI::Node::Some::Node.
 
-=item 3
+=item 3)
 
 calls the init method as implemented in the PNI::Node::Some::Node package.
 
-=item 4
+=item 4)
 
-adds the node to the root scenario.
+adds the node to the root PNI::Scenario.
 
 =back
 
-If no type is passed, and you just write
+If no PNI type is passed, and you just write
 
     my $node = node;
     
@@ -162,6 +168,14 @@ PNI creates an empty node.
 
 This method delegates to L<PNI::Node> constructor.
 
+=head2 C<node_list>
+
+    my @nodes = PNI::node_list;
+
+Returns a list of available PNI nodes.
+
+This method delegates to L<PNI::Finder> C<nodes> method.
+
 =head2 C<task>
 
 Calls the task method for every loaded node.
@@ -171,13 +185,19 @@ This method delegates to the root scenario task method.
 
 Starts the PNI main loop. It keeps calling C<task> as fast as it can.
 
+=head2 C<root>
+
+    my $root = PNI::root;
+
+Returns the root PNI::Scenario.
+
 =head1 SEE ALSO
 
-L<PNI::Node::Perlfunc>
+L<PNI::Edge>
 
-L<PNI::Node::Perlop>
+L<PNI::Node>
 
-L<PNI::Node::Perlvar>
+L<PNI::Scenario>
 
 
 
