@@ -1,7 +1,8 @@
 package PNI::Error;
 use strict;
 use warnings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
+### use Smart::Comments;
 
 my $verbose = 1;
 
@@ -10,15 +11,26 @@ sub verbose_off { $verbose = 0; return 1; }
 sub verbose_on { $verbose = 1; return 1; }
 
 my $say = sub {
-    my ( $package, $filename, $line ) = caller 1;
+    my ( $package, $filename, $line ) = caller 2;
     if ($verbose) {
         my $message = shift;
-        warn "PNI::Error message: $message\n";
-        warn "from package $package in file $filename at line $line\n";
+        warn "[PNI::Error] message: $message\n";
+        warn
+"[PNI::Error] from package $package in file $filename at line $line\n";
     }
     return 1;
 };
 
+sub attribute_does_not_exists {
+    $say->('attribute does not exists');
+    return;
+}
+
+sub check_data_failed {
+    $say->('check data failed');
+    return;
+}
+
 sub generic {
     $say->('generic');
     return;
@@ -60,12 +72,41 @@ sub unimplemented_abstract_method {
 }
 
 1;
+__END__
 
 =head1 NAME
 
-PNI::Error - errors catalogue
+PNI::Error - PNI errors catalogue
 
 
+=head1 METHODS
+
+=head2 C<verbose_off>
+
+=head2 C<verbose_on>
+
+=head1 ERRORS
+
+=head2 C<attribute_does_not_exists>
+
+=head2 C<check_data_failed>
+
+=head2 C<generic>
+
+=head2 C<invalid_argument_type>
+
+=head2 C<missing_required_argument>
+
+=head2 C<unable_to_create_item>
+
+=head2 C<unable_to_init_node>
+
+=head2 C<unable_to_load_node>
+
+=head2 C<unable_to_run_task>
+
+=head2 C<unimplemented_abstract_method>
+
 
 
 =head1 AUTHOR
