@@ -1,7 +1,8 @@
 package PNI::Node::List::Util::Max;
 use strict;
 use warnings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
+### use Smart::Comments;
 use base 'PNI::Node';
 
 use List::Util 'max';
@@ -9,9 +10,9 @@ use List::Util 'max';
 sub init {
     my $node = shift;
 
-    $node->add_input('in');
+    my $in = $node->add_input('in');
 
-    $node->add_output('out');
+    my $out = $node->add_output('out');
 
     return 1;
 }
@@ -19,8 +20,10 @@ sub init {
 sub task {
     my $node = shift;
 
-    my $in  = $node->get_input('in');
+    my $in = $node->get_input('in');
+
     my $out = $node->get_output('out');
+
     my $result;
 
     if ( $in->is_array ) {
@@ -41,6 +44,20 @@ PNI::Node::List::Util::Max - PNI node wrapping the List::Util max function
 
 
 
+=head1 INPUTS
 
+=over 4
+
+=item in
+
+=back
+
+=head1 OUTPUTS
+
+=over 4
+
+=item out
+
+=back
 
 =cut
