@@ -1,13 +1,14 @@
 package PNI::Node::Perlfunc::Sleep;
 use strict;
 use warnings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
+### use Smart::Comments;
 use base 'PNI::Node';
 
 sub init {
     my $node = shift;
 
-    $node->add_input('in');
+    my $in = $node->add_input('in');
 
     return 1;
 }
@@ -28,11 +29,23 @@ sub task {
 
 =head1 NAME
 
-PNI::Node::Perlfunc::Sleep - PNI node wrapping the Perl sleep function
+PNI::Node::Perlfunc::Sleep - PNI node wrapping the Perl C<sleep> function
 
 
 
 
+=head1 INPUTS
 
+=over 4
+
+=item in
+
+=back
+
+=head1 OUTPUTS
+
+=over 4
+
+=back
 
 =cut
