@@ -1,7 +1,8 @@
 package PNI::Node::Scalar::Util::Looks_like_number;
 use strict;
 use warnings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
+### use Smart::Comments;
 use base 'PNI::Node';
 
 use Scalar::Util 'looks_like_number';
@@ -9,9 +10,18 @@ use Scalar::Util 'looks_like_number';
 sub init {
     my $node = shift;
 
-    $node->add_input('in');
+    my $in = $node->add_input('in');
 
-    $node->add_output('out');
+    my $out = $node->add_output('out');
+
+    if ( $in->is_defined ) {
+        my $in_data  = $in->get_data;
+        my $out_data = looks_like_number($in_data);
+        $out->set_data($out_data);
+    }
+    else {
+        $out->set_data(undef);
+    }
 
     return 1;
 }
@@ -19,7 +29,8 @@ sub init {
 sub task {
     my $node = shift;
 
-    my $in  = $node->get_input('in');
+    my $in = $node->get_input('in');
+
     my $out = $node->get_output('out');
 
     if ( $in->is_defined ) {
@@ -43,6 +54,20 @@ PNI::Node::Scalar::Util::Looks_like_number - PNI node wrapping the Scalar::Util
 
 
 
+=head1 INPUTS
 
+=over 4
+
+=item in
+
+=back
+
+=head1 OUTPUTS
+
+=over 4
+
+=item out
+
+=back
 
 =cut
