@@ -1,16 +1,18 @@
 package PNI::Slot::In;
 use strict;
 use warnings;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
+### use Smart::Comments;
 use base 'PNI::Slot';
-use PNI::Error 0.14;
+use PNI::Edge 0.15;
+use PNI::Error 0.15;
 
 sub new {
     my $class = shift;
     my $arg   = {@_};
+    my $self  = $class->SUPER::new(@_)
+      or return PNI::Error::unable_to_create_item;
 
-    # call the Slot constructor and check result
-    my $self = $class->SUPER::new(@_) or return;
     $self->add('edge');
 
     return $self;
@@ -25,6 +27,7 @@ sub add_edge {
 
 sub get_edge { return shift->get('edge'); }
 
+# return 0 or 1
 sub is_connected {
     my $self = shift;
     my $edge = $self->get_edge;
@@ -32,13 +35,34 @@ sub is_connected {
     else                   { return 0; }
 }
 
+# return $edge
+sub join_to {
+    my $self = shift;
+
+    # output_slot arg is required
+    my $output_slot = shift or return PNI::Error::missing_required_argument;
+
+    return PNI::Edge->new( target => $self, source => $output_slot );
+}
+
 1;
+__END__
 
 =head1 NAME
 
 PNI::Slot::In - input slot
 
 
+=head1 METHODS
+
+=head2 C<add_edge>
+
+=head2 C<get_edge>
+
+=head2 C<is_connected>
+
+=head2 C<join_to>
+
 
 
 =head1 AUTHOR
